#  Authors and Acknowledgments

**ReaxKit** was primarily developed by:

- **Ali Mohammadi Dinani** – Project lead; design, and architecture; developing handlers, analyzers, and workflows
- **Adri van Duin** - Supervision and support for ReaxKit; developing `xtob.f` and `place2.f` fortran codes used in `geo_generator.py`; developing ReaxFF

### Code Contributions and Collaborations 


Parts of this codebase were inspired by or adapted from work contributed by:

- **[Yun Kyung Shin]** – developed the `elastic_energy.f` and `elastic_geo.f` fortran codes used in `trainset_generator.py`
- **[Alireza Sepehrinezhad]** – developed the initial version of `make_eregime_sinusoidal` used in `eregime_generator.py` and `dipole_analyzer.py` code used in the `electrostatics_analyzers.py`

Their original contributions have been modified and integrated with permission.

---

If you believe your contributions or ideas are reflected here and you’re not yet listed, please contact the maintainer.
